==> nextcloud-25.0.8.tgz: nextcloud/apps/photos/l10n/sr.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Јавна веза",
    "Photos" : "Слике",
    "Your memories under your control" : "Ваше успомене под Вашом контролом",
    "All media" : "Сви медији",
    "Videos" : "Видео снимци",
    "Albums" : "Албуми",
    "Collaborative albums" : "Заједнички албуми",
    "People" : "Људи",
    "Folders" : "Фасцикле",
    "Favorites" : "Омиљене",
    "On this day" : "На данашњи дан",
    "Shared with you" : "Дељено са Вама",
    "Tags" : "Ознаке",
    "Places" : "Места",
    "Map" : "Мапа",
    "Photos settings" : "Подешавања",
    "Mark selection as favorite" : "Означи изабрано као омиљено",
    "Add selection to favorites" : "Додај изабрано у омиљено",
    "Remove selection from favorites" : "Уклони изабрано из омиљених",
    "Name of the album" : "Назив албума",
    "Location of the album" : "Локација албума",
    "Go back to the previous view." : "Повратак на претходни поглед.",
    "Back" : "Назад",
    "Go to the add collaborators view." : "Враћање на поглед додавања сарадника",
    "Add collaborators" : "Додај сараднике",
    "Save." : "Сачувај.",
    "Create the album." : "Креирање албума.",
    "Save" : "Сачувај",
    "Create album" : "Креирај албум",
    "Back to the new album form." : "Повратак на форму новог албума.",
    "Add to Album" : "Додај албум",
    "Add selection to album {albumName}" : "Додај изабрано у албум {albumName}",
    "Shared by" : "Поделио",
    "Create a new album." : "Креирање новог албума.",
    "Create new album" : "Креирај албум",
    "New album" : "Нови албум",
    "_%n item_::_%n photos and videos_" : ["%n ставка","%n фотографије и видео снимка","%n форографија и видео снимака"],
    "Add people or groups who can edit your album" : "Додај људе или групе које могу да уређују ваш албум",
    "Search people or groups" : "Претрага људи и група",
    "No recommendations. Start typing." : "Нема препорука. Започните куцање.",
    "Group" : "Група",
    "Remove {collaboratorLabel} from the collaborators list" : "Уклони {collaboratorLabel} из листе сарадника",
    "Copy the public link" : "Копирај јавни линк",
    "Public link copied!" : "Јавни линк је корипан!",
    "Copy public link" : "Копирај јавни линк",
    "Delete the public link" : "Обриши јавни линк",
    "Create public link share" : "Направи дељење јавном везом",
    "Share via public link" : "Подели путем јавног линка",
    "Failed to fetch collaborators list." : "Није успело добављање листе сарадника.",
    "Failed to update album." : "Није успело ажурирање албума.",
    "This collection does not exist" : "Ова колекција не постоји",
    "An error occurred" : "Догодила се грешка",
    "_%n photos_::_%n photos_" : ["%n фотографија","%n фотографије","%n фотографија"],
    "_%n unassigned photo_::_%n unassigned photos_" : ["%n недодељена фотографија","%n недодељене фотографије","%n недодељених фотографија"],
    "Select image {imageName}" : "Изабери слику {imageName}",
    "The file is in the favorites" : "Фајл се налази у омиљенима",
    "Open the full size \"{name}\" image" : "Отвори слику „{name}” у пуној величини",
    "There are no photos or videos yet!" : "Још увек нема фотографија или видео снимака!",
    "Add to {destination}" : "Додај у {destination}",
    "Open the \"{name}\" sub-directory" : "Отвори „{name}” поддиректоријум",
    "Back to {folder}" : "Назад у {folder}",
    "Share this folder" : "Дели ову фасциклу",
    "_{years} year ago_::_{years} years ago_" : ["пре {years} године","пре {years} године","пре {years} година"],
    "Enable squared photos view" : "Укључи квадратасти приказ слика",
    "Default Photos upload and Albums location" : "Подразумевано место за отпремање фотографија и албума",
    "Choose default Photos upload and Albums location" : "Изаберите подразумевано место за отпремање Фотографија и албума",
    "Select the default location for your media" : "Изаберите подразумевано место за своје медије",
    "Invalid location selected" : "Изабрана је неисправна локација",
    "View" : "Погледај",
    "Photos directory" : "Директоријум фотографија",
    "_%n photo_::_%n photos_" : ["%n фотографија","%n фотографије","%n фотографија"],
    "Manage collaborators for this album" : "Управљање сарадницима на овом албуму",
    "Open actions menu" : "Отвори мени са акцијама",
    "Edit album details" : "Уреди детаље о албуму",
    "Download all files in album" : "Преузми све фајлове у албуму",
    "Delete album" : "Обриши албум",
    "Download selected files" : "Преузми изабране фајлове",
    "Remove selection from album" : "Уклони избор са албума",
    "This album does not have any photos or videos yet!" : "Овај албум још увек нема ниједну фотографију или видео снимак!",
    "Add photos to this album" : "Додај фотографије у овај албум",
    "Manage collaborators" : "Управљај сарадницима",
    "Save collaborators for this album." : "Сачувај сараднике на овом албуму",
    "Cover photo for album {albumName}" : "Фотографија омота за албум {albumName}",
    "There is no album yet!" : "Још увек нема албума!",
    "This person could not be found" : "Ова особа не може да се пронађе",
    "Rename person" : "Промени име особе",
    "Merge with different person" : "Споји са другом особом",
    "Download selected photos" : "Преузми изабране фотографије",
    "Favorite" : "Омиљени",
    "Remove from favorites" : "Уклони из омиљених",
    "Remove person" : "Уклони особу",
    "Name of this person" : "Име ове особе",
    "Merge person" : "Споји особу",
    "Move to different person" : "Премести другој особи",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Премести фотографију другој особи","Премести фотографије другој особи","Премести фотографије другој особи"],
    "_Remove photo from person_::_Remove photos from person_" : ["Уклони фотографију особи","Уклони фотографије особи","Уклони фотографије особи"],
    "This might take some time depending on the size of your photo library." : "У зависности од величине ваше фото библиотеке, ово може да потраје неко време.",
    "Recognized people will show up here" : "Овде ће се појавити препознате особе",
    "This folder does not exist" : "Овај фолдер не постоји",
    "Loading folders …" : "Учитавање фолдера ...",
    "No photos in here" : "Овде нема слика",
    "This place does not have any photos or videos yet!" : "Ово место још увек нема ниједну фотографију или видео снимак!",
    "Add photos to this place" : "Додај фотографије на ово место",
    "Cover photo for place {placeName}" : "Фотографија омота за место {placeName}",
    "There is no place yet!" : "Још увек нема места!",
    "Cover photo for shared album {albumName}." : "Фотографија омота за дељени албум {albumName}.",
    "Back to tags overview" : "Назад на преглед ознака",
    "No photos with this tag yet" : "Још увек нема фотографија са овом ознаком",
    "No tags yet" : "Још нема ознака",
    "Photos with tags will show up here" : "Слике са ознакама ће се појавити овде",
    "Popular tags" : "Популарне ознаке",
    "Add" : "Додај",
    "Create a new album" : "Креирај нови албум",
    "Add selection to an album" : "Додај изабрано у албум",
    "Add to album" : "Додај у албум",
    "Delete selection" : "Обриши одабир",
    "No photos or videos in here" : "Овде нема фотографија или видео снимака",
    "Unassigned faces" : "Недодељена лица",
    "Failed to fetch collection." : "Није успело добављање колекције.",
    "Failed to fetch collections list." : "Није успело добављање листе колекција.",
    "Failed to fetch faces list." : "Није успело добављање листе лица.",
    "All your media" : "Сви ваши медији",
    "Album {title}" : "Албум {title}",
    "Shared Albums" : "Дељени албуми",
    "Shared album {title}" : "Дељени албум {title}",
    "Public album {title}" : "Јавни албум {title}",
    "Tagged photos" : "Слике са ознаком",
    "Tagged photo {title}" : "Означена фотографија {title}",
    "{title}'s face" : "лице {title}",
    "Failed to rename {oldName} to {faceName}." : "Није успела промена имена {oldName} у {faceName}.",
    "Failed to delete {faceName}." : "Није успело брисање {faceName}.",
    "Failed to delete {fileId}." : "Није успело брисање {fileId}.",
    "Failed to delete {fileName}." : "Није успело брисање {fileName}.",
    "Failed to set favorite state for {fileId}." : "Није успело постављање стања омиљено за {fileId}.",
    "Failed to set favorite state for {fileName}." : "Није успело постављање стања омиљено за {fileName}.",
    "Locations" : "Локације",
    "_Share with %n user_::_Share with %n users_" : ["Подели са %n корисником","Подели са %n корисника","Подели са %n корисника"],
    "Search for collaborators" : "Претрага сарадника",
    "Add {collaboratorLabel} to the collaborators list" : "Додај {collaboratorLabel} на листу сарадника",
    "No collaborators available" : "Нема достуоних сарадника",
    "Failed to fetch album." : "Није успело добављање албума.",
    "Add photos to the album" : "Додај фотографије у албум",
    "Failed to fetch albums list." : "Није успело добављање листе албума.",
    "Shared albums" : "Дељени албуми",
    "Failed to create {albumName}." : "{albumName} није могао да се креира.",
    "Failed to rename {currentAlbumName} to {newAlbumName}." : "Није успела промена имена {currentAlbumName} у {newAlbumName}."
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> nextcloud-26.0.11p1.tgz: nextcloud/apps/photos/l10n/sr.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Јавна веза",
    "Photos" : "Слике",
    "Your memories under your control" : "Ваше успомене под Вашом контролом",
    "All media" : "Сви медији",
    "Videos" : "Видео снимци",
    "Albums" : "Албуми",
    "Collaborative albums" : "Заједнички албуми",
    "People" : "Људи",
    "Folders" : "Фасцикле",
    "Favorites" : "Омиљене",
    "On this day" : "На данашњи дан",
    "Shared with you" : "Дељено са Вама",
    "Tags" : "Ознаке",
    "Places" : "Места",
    "Map" : "Мапа",
    "Photos settings" : "Подешавања",
    "Mark selection as favorite" : "Означи изабрано као омиљено",
    "Add selection to favorites" : "Додај изабрано у омиљено",
    "Remove selection from favorites" : "Уклони изабрано из омиљених",
    "Name of the album" : "Назив албума",
    "Location of the album" : "Локација албума",
    "Back" : "Назад",
    "Add collaborators" : "Додај сараднике",
    "Save" : "Сачувај",
    "Create album" : "Креирај албум",
    "Add to Album" : "Додај албум",
    "Add selection to album {albumName}" : "Додај изабрано у албум {albumName}",
    "Shared by" : "Поделио",
    "Create a new album." : "Креирање новог албума.",
    "Create new album" : "Креирај албум",
    "New album" : "Нови албум",
    "_%n item_::_%n photos and videos_" : ["%n ставка","%n фотографије и видео снимка","%n форографија и видео снимака"],
    "Add people or groups who can edit your album" : "Додај људе или групе које могу да уређују ваш албум",
    "Search people or groups" : "Претрага људи и група",
    "No recommendations. Start typing." : "Нема препорука. Започните куцање.",
    "Group" : "Група",
    "Remove {collaboratorLabel} from the collaborators list" : "Уклони {collaboratorLabel} из листе сарадника",
    "Copy the public link" : "Копирај јавни линк",
    "Public link copied!" : "Јавни линк је корипан!",
    "Copy public link" : "Копирај јавни линк",
    "Delete the public link" : "Обриши јавни линк",
    "Create public link share" : "Направи дељење јавном везом",
    "Share via public link" : "Подели путем јавног линка",
    "Failed to fetch collaborators list." : "Није успело добављање листе сарадника.",
    "Failed to update album." : "Није успело ажурирање албума.",
    "This collection does not exist" : "Ова колекција не постоји",
    "An error occurred" : "Догодила се грешка",
    "_%n unassigned photo_::_%n unassigned photos_" : ["%n недодељена фотографија","%n недодељене фотографије","%n недодељених фотографија"],
    "Favorite" : "Омиљени",
    "Select image {imageName}" : "Изабери слику {imageName}",
    "Open the full size \"{name}\" image" : "Отвори слику „{name}” у пуној величини",
    "There are no photos or videos yet!" : "Још увек нема фотографија или видео снимака!",
    "Add to {destination}" : "Додај у {destination}",
    "Open the \"{name}\" folder" : "Отвори „{name}” директоријум",
    "Go back" : "Иди назад",
    "Back to {folder}" : "Назад у {folder}",
    "Share this folder" : "Дели ову фасциклу",
    "_{years} year ago_::_{years} years ago_" : ["пре {years} године","пре {years} године","пре {years} година"],
    "Enable squared photos view" : "Укључи квадратасти приказ слика",
    "Default Photos upload and Albums location" : "Подразумевано место за отпремање фотографија и албума",
    "Choose default Photos upload and Albums location" : "Изаберите подразумевано место за отпремање Фотографија и албума",
    "Select the default location for your media" : "Изаберите подразумевано место за своје медије",
    "Invalid location selected" : "Изабрана је неисправна локација",
    "View" : "Погледај",
    "Photos directory" : "Директоријум фотографија",
    "_%n photo_::_%n photos_" : ["%n фотографија","%n фотографије","%n фотографија"],
    "Unselect all" : "Поништи цео избор",
    "Manage collaborators for this album" : "Управљање сарадницима на овом албуму",
    "Open actions menu" : "Отвори мени са акцијама",
    "Edit album details" : "Уреди детаље о албуму",
    "Download all files in album" : "Преузми све фајлове у албуму",
    "Delete album" : "Обриши албум",
    "Download selected files" : "Преузми изабране фајлове",
    "Remove selection from album" : "Уклони избор са албума",
    "This album does not have any photos or videos yet!" : "Овај албум још увек нема ниједну фотографију или видео снимак!",
    "Add photos to this album" : "Додај фотографије у овај албум",
    "Add photos to {albumName}" : "Додај фотографије у {albumName}",
    "Manage collaborators" : "Управљај сарадницима",
    "Save collaborators for this album." : "Сачувај сараднике на овом албуму",
    "Cover photo for album {albumName}" : "Фотографија омота за албум {albumName}",
    "There is no album yet!" : "Још увек нема албума!",
    "This person could not be found" : "Ова особа не може да се пронађе",
    "Rename person" : "Промени име особе",
    "Merge with different person" : "Споји са другом особом",
    "Download selected photos" : "Преузми изабране фотографије",
    "Remove from favorites" : "Уклони из омиљених",
    "Remove person" : "Уклони особу",
    "Name of this person" : "Име ове особе",
    "Save." : "Сачувај.",
    "Merge person" : "Споји особу",
    "Move to different person" : "Премести другој особи",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Премести фотографију другој особи","Премести фотографије другој особи","Премести фотографије другој особи"],
    "_Remove photo from person_::_Remove photos from person_" : ["Уклони фотографију особи","Уклони фотографије особи","Уклони фотографије особи"],
    "This might take some time depending on the size of your photo library." : "У зависности од величине ваше фото библиотеке, ово може да потраје неко време.",
    "Recognized people will show up here" : "Овде ће се појавити препознате особе",
    "This folder does not exist" : "Овај фолдер не постоји",
    "Loading folders …" : "Учитавање фолдера ...",
    "No photos in here" : "Овде нема слика",
    "Taken on {date} at {time}" : "Сликано дана {date} у {time}",
    "This place does not have any photos or videos yet!" : "Ово место још увек нема ниједну фотографију или видео снимак!",
    "Add photos to this place" : "Додај фотографије на ово место",
    "Cover photo for place {placeName}" : "Фотографија омота за место {placeName}",
    "There is no place yet!" : "Још увек нема места!",
    "Cover photo for shared album {albumName}." : "Фотографија омота за дељени албум {albumName}.",
    "Back to tags overview" : "Назад на преглед ознака",
    "No photos with this tag yet" : "Још увек нема фотографија са овом ознаком",
    "No tags yet" : "Још нема ознака",
    "Photos with tags will show up here" : "Слике са ознакама ће се појавити овде",
    "Popular tags" : "Популарне ознаке",
    "Add" : "Додај",
    "Add to album" : "Додај у албум",
    "Delete selection" : "Обриши одабир",
    "No photos or videos in here" : "Овде нема фотографија или видео снимака",
    "Unassigned faces" : "Недодељена лица",
    "_%n photos_::_%n photos_" : ["%n фотографија","%n фотографије","%n фотографија"],
    "Failed to fetch collection." : "Није успело добављање колекције.",
    "Failed to fetch collections list." : "Није успело добављање листе колекција.",
    "Failed to fetch faces list." : "Није успело добављање листе лица.",
    "All your media" : "Сви ваши медији",
    "Album {title}" : "Албум {title}",
    "Shared Albums" : "Дељени албуми",
    "Shared album {title}" : "Дељени албум {title}",
    "Public album {title}" : "Јавни албум {title}",
    "Tagged photos" : "Слике са ознаком",
    "Tagged photo {title}" : "Означена фотографија {title}",
    "{title}'s face" : "лице {title}",
    "{startDate} to {endDate}" : "{startDate} до {endDate}",
    "Details" : "Детаљи",
    "Failed to rename {oldName} to {faceName}." : "Није успела промена имена {oldName} у {faceName}.",
    "Failed to delete {faceName}." : "Није успело брисање {faceName}.",
    "Failed to delete {fileId}." : "Није успело брисање {fileId}.",
    "Failed to delete {fileName}." : "Није успело брисање {fileName}.",
    "Failed to set favorite state for {fileId}." : "Није успело постављање стања омиљено за {fileId}.",
    "Failed to set favorite state for {fileName}." : "Није успело постављање стања омиљено за {fileName}.",
    "Go back to the previous view." : "Повратак на претходни поглед.",
    "Go to the add collaborators view." : "Враћање на поглед додавања сарадника",
    "Create the album." : "Креирање албума.",
    "Back to the new album form." : "Повратак на форму новог албума.",
    "_Share with %n user_::_Share with %n users_" : ["Подели са %n корисником","Подели са %n корисника","Подели са %n корисника"],
    "Search for collaborators" : "Претрага сарадника",
    "Add {collaboratorLabel} to the collaborators list" : "Додај {collaboratorLabel} на листу сарадника",
    "No collaborators available" : "Нема достуоних сарадника",
    "Failed to fetch album." : "Није успело добављање албума.",
    "The file is in the favorites" : "Фајл се налази у омиљенима",
    "Open the \"{name}\" sub-directory" : "Отвори „{name}” поддиректоријум",
    "Add photos to the album" : "Додај фотографије у албум",
    "Failed to fetch albums list." : "Није успело добављање листе албума.",
    "Shared albums" : "Дељени албуми",
    "Create a new album" : "Креирај нови албум",
    "Add selection to an album" : "Додај изабрано у албум",
    "Failed to create {albumName}." : "{albumName} није могао да се креира.",
    "Failed to rename {currentAlbumName} to {newAlbumName}." : "Није успела промена имена {currentAlbumName} у {newAlbumName}."
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
